@@ -14,6 +14,9 @@
  */
 
 /* Functions used to display statistics in SVG */
+__print_funct_t svg_print_cpu_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
 __print_funct_t svg_print_pcsw_stats
 	(struct activity *, int, int, struct svg_parm *, unsigned long long,
 	 struct record_header *);
@@ -23,8 +26,17 @@ __print_funct_t svg_print_swap_stats
 __print_funct_t svg_print_paging_stats
 	(struct activity *, int, int, struct svg_parm *, unsigned long long,
 	 struct record_header *);
+__print_funct_t svg_print_memory_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
+__print_funct_t svg_print_queue_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
 __print_funct_t svg_print_net_dev_stats
 	(struct activity *, int, int, struct svg_parm *, unsigned long long,
 	 struct record_header *);
+__print_funct_t svg_print_pwr_cpufreq_stats
+	(struct activity *, int, int, struct svg_parm *, unsigned long long,
+	 struct record_header *);
 	
 #endif /* _SVG_STATS_H */
